package com.xy.service.factory;

import cn.hutool.json.JSONObject;
import com.xy.dto.ActivityInfoDto;
import com.xy.dto.MqttDto;
import com.xy.entity.DeviceLog;
import com.xy.service.ActivityInfoService;
import com.xy.service.DeviceLogServiceImpl;
import com.xy.utils.LambdaUtils;
import com.xy.utils.R;
import com.xy.utils.enums.TaskEnum;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 任务指令 接口实现
 */
@Service
@RequiredArgsConstructor
public class TaskCmdServiceImpl implements CmdService {

    private final ActivityInfoService activityInfoService;

    private final DeviceLogServiceImpl deviceLogService;

    @Override
    public R senCommand(List<MqttDto> mqttDtos) {
        for (MqttDto mqttDto : mqttDtos) {
            JSONObject data = mqttDto.getPater().getData();
            String type = data.getStr(LambdaUtils.getProperty(TaskEnum::getType));
            //终止活动
            if (type.equals(TaskEnum.ABORT.getType())) {
                activityInfoService.abort(new ActivityInfoDto.Abort().setDeviceId(mqttDto.getDeviceId()));
            }
            //日志上传
            if (type.equals(TaskEnum.LOG.getType())) {
                DeviceLog deviceLog = new DeviceLog().createId()
                        .setDeviceId(mqttDto.getDeviceId())
                        .setCreateTime(LocalDateTime.now());
                deviceLogService.save(deviceLog);
            }
        }
        return R.ok();
    }

    @Override
    public R resultBack(MqttDto.ResultBack resultBack) {
        return R.ok();
    }
}
